<?php
namespace Teknisa\PLA\Services;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\FilterCriteria;
use \Setforms2\Shared\ORM\DateTime;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DTO;
use Doctrine\DBAL\Connection;

class Pla90000PratoEquivalenteService {
	
	protected $crudService;
	protected $parameterBag;
	protected $entityManager;
	protected $environment;
	protected $dataSourceManager;
	protected $util;
	protected $newCode;
	protected $connection;
	protected $novoCodigo;
    
    public function __construct($crudService, ParameterBag $parameterBag, $environment, $entityManager, $dataSourceManager, $util, $newCode, $connection, $novoCodigo) {
	    $this->crudService = $crudService;
	    $this->entityManager = $entityManager;
	    $this->environment = $environment;
	    $this->dataSourceManager = $dataSourceManager;
	    $this->util = $util;
	    $this->newCode = $newCode;
	    $this->connection = $connection;    
	    $this->novoCodigo = $novoCodigo;
  }
	
	public function retornaPratoEquivalente($nrEquiporato){
		$query  = 
				"SELECT 
					PE.NREQUIPRATO, 
					PE.NRPRATEQUIPRATO, 
					PE.CDFILAUXPRAT, 
					PE.CDPRATO, 
					P.NMPRATO
				FROM 
					PRATEQUIPRATO PE, 
					PRATO P
				WHERE 
					PE.CDFILAUXPRAT = P.CDFILAUXPRAT
					AND PE.CDPRATO = P.CDPRATO
					AND PE.NREQUIPRATO = :P_NREQUIPRATO";

		$params = array('P_NREQUIPRATO' => $nrEquiporato);

		$sql = $this->entityManager->getConnection()->prepare($query);
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function insertPratoPrincipal($rows){
		$query = 
				"INSERT INTO 
					EQUIPRATO(
						NREQUIPRATO, 
						CDFILAUXPRAT, 
						CDPRATO, 
						IDEQUIPRATO,
						CDFILIAL, 
						CDSERVFILI
					)
				VALUES (
						SEQ_EQUIPRATO.NEXTVAL, 
						:CDFILAUXPRAT, 
						:CDPRATO, 
						:IDEQUIPRATO, 
						:CDFILIAL, 
						:CDSERVFILI
					)";
		$params = array(
            "CDFILAUXPRAT"  => $rows['CDFILAUXPRAT'],
            "CDPRATO"		=> $rows['CDPRATO'],
            "IDEQUIPRATO"	=> $rows['IDEQUIPRATO'],
            "CDFILIAL"		=> $rows['CDFILIAL'],
            "CDSERVFILI"	=> $rows['CDSERVFILI']
        );
        
        $std = $this-> connection->prepare($query);
        $std->execute($params);
	}
	
	public function insertPratoEquivalente($rows){
		$query = 
				"INSERT INTO 
					PRATEQUIPRATO(
						NRPRATEQUIPRATO, 
						NREQUIPRATO, 
						CDFILAUXPRAT,
						CDPRATO
					)
				VALUES (
						SEQ_EQUIPRATO.NEXTVAL, 
						:NREQUIPRATO, 
						:CDFILAUXPRAT, 
						:CDPRATO
					)";
				
		$params = array(
            "NREQUIPRATO"	=> $rows['NREQUIPRATO'],
            "CDFILAUXPRAT"	=> $rows['CDFILAUXPRAT'],
            "CDPRATO"		=> $rows['CDPRATO']
        );
        
        $std = $this->connection->prepare($query);
        $std->execute($params);
	}
	
	public function deletaPratoEquivalente($rows){
		$query = 
				"DELETE FROM PRATEQUIPRATO 
				 WHERE
					CDFILAUXPRAT	=	:CDFILAUXPRAT AND
					CDPRATO			=	:CDPRATO AND
					NREQUIPRATO		=   :NREQUIPRATO AND
					NRPRATEQUIPRATO =	:NRPRATEQUIPRATO";
					
		$params = array(
            "CDFILAUXPRAT"		=> $rows['CDFILAUXPRAT'],
            "CDPRATO"			=> $rows['CDPRATO'],
            "NREQUIPRATO"		=> $rows['NREQUIPRATO'],
            "NRPRATEQUIPRATO"	=> $rows['NRPRATEQUIPRATO']
        );
        
        $std = $this->connection->prepare($query);
        $std->execute($params);
	}
	
	public function retornaPratoParaInclusao($row){
		$query = 
			"SELECT P.NRORG, 
				P.CDPRATO, 
				P.CDFILAUXPRAT, 
				P.NMPRATO 
			FROM 
				PRATO P 
			WHERE 
				((P.CDFILAUXPRAT = 'P') OR (P.CDFILAUXPRAT = :P_CDFILIAL)) 
				AND (P.CDNVPRATO = :P_CDNVPRATO)";
		
		$params = array(
            "P_CDNVPRATO"	=> $row['CDNVPRATO'],
            "P_CDFILIAL"	=> $row['CDFILIAL']
        );
		
		$sql = $this->entityManager->getConnection()->prepare($query);
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
}